;
;   Module name      :	CmdLine.au3
;   Version          :	1.01
;   Started on       :	December 26, 2010
;   Completed on     :	December 26, 2010
;   Author           :  J.Hubb
;
;   Module type      :	Object
;   Description      :	Methods to parse command line parameters, derived from Linux Bash
;
;   Developed under  :	AutoIt 3.2.10.0
;   Sw requirements  :	None
;
;   Parameters       :	None
;   Notes - usage    :	None
;


;--- Global directives -----------------------------------------------------------------------------



#include-once

Opt("MustDeclareVars", 1)



;--- Include files ---------------------------------------------------------------------------------



;--- Public constants ------------------------------------------------------------------------------



const $CL_FILE_NAME = "CmdLine.au3"
const $CL_MODULE_VER = "1.01"
const $CL_MODULE_NAME = $CL_FILE_NAME & " " & $CL_MODULE_VER & "; Open Source library on December 26, 2010 by J.Hubb."

; Error codes
const $CL_NO_ERROR = 0

; Error code in switch recognition
const $CL_SWITCH_ERR = 0



;--- Public variables ------------------------------------------------------------------------------



;--- Private constants -----------------------------------------------------------------------------



; Indexes for fields of switch definition
enum $_LO_ID, $_LO_TEXT, $_LO_PARAM_NUM



;--- Private variables -----------------------------------------------------------------------------



global $_CL_get_opts_ndx = 0



;--- Public functions code -------------------------------------------------------------------------



func CLGetOpts(const byref $def, byref $s, byref $s_ndx, byref $p_ndx)
;---
; Parses the next command line parameter to search for switches defined by $def.
;
; $def		array with definitions of switches; every entry is an inner array in the form:
;				[Id, Text, Num_param]
;			where:
;				Id			the constant to identify the switch
;				Text		the text that defines the switch on command line (i.e. "/?", "/ver", ...)
;				Num_param	the number of following required parameters for this switch
;			The first inner array must always be:
;				[$CL_SWITCH_ERR, "", 0]
; $s		recognized switch (first element of each definition $def) or error
; $s_ndx	index on command line of recognized or invalid switch
; $p_ndx	index on command line of first parameters for $s or undefined if not used
; ret		False if command line parameters are ended, else True
;---
	local $param_num = $CmdLine[0]
	local $n = UBound($def) - 1
	local $p_num
	
	$_CL_get_opts_ndx += 1
	if ($_CL_get_opts_ndx <= $param_num) then
		while (($n > 0) and not ($def[$n][$_LO_TEXT] = $CmdLine[$_CL_get_opts_ndx]))	; "=" case insensitive
			$n -= 1
		wend
		$s = $def[$n][$_LO_ID]
		$s_ndx = $_CL_get_opts_ndx
		if ($s <> $CL_SWITCH_ERR) then				; Switch found
			$p_num = $def[$n][$_LO_PARAM_NUM]
			if (($_CL_get_opts_ndx + $p_num) <= $param_num) then
				$p_ndx = $_CL_get_opts_ndx + 1		; Enough parameters on command line
				$_CL_get_opts_ndx += $p_num			; Move to the last parameter used in this run
			else
				$s = $CL_SWITCH_ERR					; Not enough parameters on command line
			endif
		endif
		return ($_CL_get_opts_ndx <= $param_num)
	else
		return False
	endif
endfunc



func CLResetOpts()
;---
; Resets the command line parameters parsing and restarts from the first one.
; It needs to be called if parsing must re-start when changing the array that
; defines switches.
;
; ret	nothing
;---
	$_CL_get_opts_ndx = 0
endfunc



;--- Private functions code ------------------------------------------------------------------------



;--- Initialization code ---------------------------------------------------------------------------


